@@ -23,13 +23,18 @@ from aliyunpan.cli.cli import Commander
 @click.option('-a', '--album', is_flag=True, help='Specify album.')
 @click.option('-s', '--share-id', type=click.STRING, help='Specify share_id.')
 @click.option('-sp', '--share-pwd', type=click.STRING, help='Specify share_pwd.')
-def cli(config_file, refresh_token, username, password, depth, debug, timeout, drive_id, album, share_id, share_pwd):
+@click.option('-f', '--filter-file', multiple=True, type=click.STRING, help='Filter files.')
+@click.option('-w', '--whitelist', is_flag=True, help='Filter files using whitelist.')
+@click.option('-m', '--match', is_flag=True, help='Specify to use regular matching files.')
+def cli(config_file, refresh_token, username, password, depth, debug, timeout, drive_id, album, share_id, share_pwd,
+        filter_file, whitelist, match):
     logger.info(f'Version:{__version__}')
     if debug:
         logger.setLevel('DEBUG')
     commander.init(config_file=None if refresh_token or username else config_file,
                    refresh_token=None if username else refresh_token, username=username, password=password, depth=depth,
-                   timeout=timeout, drive_id=drive_id, album=album, share_id=share_id, share_pwd=share_pwd)
+                   timeout=timeout, drive_id=drive_id, album=album, share_id=share_id, share_pwd=share_pwd,
+                   filter_file=set(filter_file), whitelist=whitelist, match=match)
 
 
 @cli.command(aliases=['l', 'list', 'dir'], help='List files.')
@@ -86,7 +91,7 @@ def upload(path, file, upload_path, time_out, retry, force, share, chunk_size, c
     if not path and not file:
         raise click.MissingParameter(param=click.get_current_context().command.params[2])
     else:
-        path_list = {*file, path}
+        path_list = set(filter(None, {*file, path}))
     commander.upload(path_list, upload_path, time_out, retry, force, share, chunk_size, c)
 
 
@@ -114,7 +119,10 @@ def download(ctx, path, file, save_path, share, chunk_size, aria2):
         file_list = {*file, path}
     kwargs = {}
     for i in ctx.args:
-        kwargs[i.split('=')[0]] = i.split('=')[1]
+        if '=' in i:
+            kwargs[i.split('=')[0]] = i.split('=')[1]
+        else:
+            kwargs[i.strip('-')] = True
     commander.download(file_list, save_path=save_path, share=share, chunk_size=chunk_size, aria2=aria2, **kwargs)
 
 
@@ -159,16 +167,30 @@ def cat(path, encoding):
     click.echo(commander.cat(path, encoding))
 
 
-@cli.command(aliases=['sync'], help='Synchronize files.')
+@cli.command(aliases=['sync'], help='Synchronize files.',
+             context_settings=dict(ignore_unknown_options=True, allow_extra_args=True))
 @click.help_option('-h', '--help')
-@click.argument('path', type=click.Path())
-@click.argument('upload_path', default='root')
+@click.argument('local_path', type=click.Path())
+@click.argument('remote_path', default='root')
 @click.option('-cs', '--chunk-size', type=click.INT, help='Chunk size(byte).')
 @click.option('-t', '--time-out', type=click.FLOAT, help='Chunk upload timeout(sec).', default=10.0, show_default=True)
 @click.option('-r', '--retry', type=click.INT, help='number of retries.', default=3, show_default=True)
-@click.option('--sync-time', type=click.FLOAT, help='Synchronization interval time(sec).')
-def sync(path, upload_path, time_out, chunk_size, retry, sync_time):
-    commander.sync(path, upload_path, sync_time, time_out, chunk_size, retry)
+@click.option('-st', '--sync-time', type=click.FLOAT, help='Synchronization interval time(sec).')
+@click.option('-n', '--no-delete', is_flag=True, help='Do not delete the cloud/local files.')
+@click.option('-d', '--delete', is_flag=True, help='Allow deletion of cloud/local files.')
+@click.option('-l', '--local', is_flag=True, help='Sync cloud drive files to local.')
+@click.pass_context
+def sync(ctx, local_path, remote_path, time_out, chunk_size, retry, sync_time, no_delete, delete, local):
+    kwargs = {}
+    for i in ctx.args:
+        if '=' in i:
+            kwargs[i.split('=')[0]] = i.split('=')[1]
+        else:
+            kwargs[i.strip('-')] = True
+    if local:
+        commander.sync_local(remote_path, local_path, sync_time, chunk_size, delete, **kwargs)
+    else:
+        commander.sync(local_path, remote_path, sync_time, time_out, chunk_size, retry, delete)
 
 
 @cli.command(aliases=['tui'], help='Text-based User Interface.')
